BaseOAuthAccessControl class abstract
- Implemented types
Constructors
- BaseOAuthAccessControl(Client? oauthClient)
Properties
- client → Client
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized ↔ bool
-
getter/setter pair
- oauthClient ↔ Client?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
Bearer access token string suitable for an
Authorizationheader.no setteroverride
Methods
-
checkAccessToken(
) → Future< void> -
inherited
-
init(
) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited