OAuthAccessControl class abstract

Implementers

Constructors

OAuthAccessControl([Client? oauthClient])
Creates a platform-specific OAuthAccessControl.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
Bearer access token string suitable for an Authorization header.
no setter

Methods

checkAccessToken() → Future<void>
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited