OAuthAccessControl constructor

OAuthAccessControl([
  1. Client? oauthClient
])

Creates a platform-specific OAuthAccessControl.

When oauthClient is supplied the caller is assumed to have already performed the OAuth 2.0 flow and the implementation will use the supplied client directly. When null, the implementation loads (and possibly obtains) credentials from disk.

Implementation

factory OAuthAccessControl([oauth2.Client? oauthClient]) =>
    getOAuthAccessControl(oauthClient);