yt library

The YouTube Live Streaming API reference explains how to schedule live broadcasts and video streams on YouTube using the YouTube Live Streaming API.

The YouTube Data API lets you incorporate functions normally executed on the YouTube website into your own website or application.

Classes

Activities
An activity resource contains information about an action that a particular channel, or user, has taken on YouTube.
Activity
An activity resource contains information about an action that a particular channel, or user, has taken on YouTube.
ActivityContentDetails
The contentDetails object contains information about the content associated with the activity.
ActivityContentPlaylistItem
Contains information about a new playlist item.
ActivityContentRecommendation
Contains information about a recommended resource.
ActivityContentResource
Contains information about a resource which is the target of a user activity.
ActivityContentSocial
Contains details about a social network post.
ActivityContentUpload
Contains information about the uploaded video.
ActivityListResponse
Returns a collection of YouTube activity events that match the request criteria.
ActivitySnippet
The snippet object contains basic details about the activity, including the activity's type and group ID.
Analytics
AnalyticsGroup
AnalyticsGroupItem
AnalyticsGroupItemListResponse
AnalyticsGroupItemResource
AnalyticsGroupListResponse
AnalyticsGroupSnippet
AnalyticsReport
AuthorChannelId
This object encapsulates information about the comment author's YouTube channel, if available.
AuthorDetails
The authorDetails object contains additional details about the user that posted this message.
Broadcast
A liveBroadcast resource represents an event that will be streamed, via live video, on YouTube.
Captions
A caption resource contains information about a YouTube video caption track.
ChannelItem
A channel resource contains information about a YouTube channel.
ChannelResponse
A channel resource contains information about a YouTube channel.
Channels
Chat
A liveChatMessage resource represents a chat message in a YouTube live chat. The resource can contain details about several types of messages, including a newly posted text message or fan funding event.
Chatbot
ColumnHeader
Comment
CommentListResponse
A comment resource contains information about a single YouTube comment. A comment resource can represent a comment about either a video or a channel. In addition, the comment could be a top-level comment or a reply to a top-level comment.
Comments
CommentThread
CommentThreadListResponse
A comment resource contains information about a single YouTube comment. A comment resource can represent a comment about either a video or a channel. In addition, the comment could be a top-level comment or a reply to a top-level comment.
CommentThreads
CredentialsPath
Helpers for resolving the file paths used to load and persist OAuth credentials.
Dialog
DialogLoader
EmojiFormatter
JwtCredentials
Keyword
LevelDetails
LiveBroadcastItem
LiveBroadcastItem Resource
LiveBroadcastResponse
LiveBroadcastResponse
LiveChatMessage
A liveChatMessage resource represents a chat message in a YouTube live chat. The resource can contain details about several types of messages, including a newly posted text message or fan funding event.
LiveChatMessageListResponse
A liveChatMessage resource represents a chat message in a YouTube live chat. The resource can contain details about several types of messages, including a newly posted text message or fan funding event.
LiveStream
A liveStream resource contains information about the video stream that you are transmitting to YouTube. The stream provides the content that will be broadcast to YouTube users. Once created, a LiveStreamItem resource can be bound to one or more LiveBroadcastItem resources.
LiveStreamItem
A liveStream resource contains information about the video stream that you are transmitting to YouTube. The stream provides the content that will be broadcast to YouTube users. Once created, a liveStream resource can be bound to one or more liveBroadcast resources.
LiveStreamListResponse
LoggingInterceptors
Dio instance may have one or more interceptors by which you can intercept requests/responses/errors before they are handled by then or catchError.
Member
MemberDetails
MemberListResponse
Members
MembershipsDetails
MembershipsDuration
MembershipsDurationAtLevel
MembershipsLevel
MembershipsLevelListResponse
MembershipsLevels
MembershipsLevelSnippet
MemberSnippet
OAuthCredentials
PhraseMatch
Playlist
A playlist resource represents a YouTube playlist. A playlist is a collection of videos that can be viewed sequentially and shared with other users. By default, playlists are publicly visible to other users, but playlists can be public or private.
PlaylistItem
A playlistItem resource identifies another resource, such as a video, that is included in a playlist. In addition, the playlistItem resource contains details about the included resource that pertain specifically to how that resource is used in that playlist.
PlaylistItemListResponse
A collection of playlist items that match the API request parameters. You can retrieve all of the playlist items in a specified playlist or retrieve one or more playlist items by their unique IDs. Try it now.
PlaylistItems
PlaylistResponse
Playlists
A playlist resource represents a YouTube playlist. A playlist is a collection of videos that can be viewed sequentially and shared with other users. By default, playlists are publicly visible to other users, but playlists can be public or private.
Position
The position object encapsulates information about the spatial position within the video where the watermark image will display.
Rating
ReportAbuse
Reports a video for containing abusive content.
A search result contains information about a YouTube video, channel, or playlist that matches the search parameters specified in an API request. While a search result points to a uniquely identifiable resource, like a video, it does not have its own persistent data.
SearchListResponse
Returns a collection of search results that match the query parameters specified in the API request. By default, a search result set identifies matching video, channel, and playlist resources, but you can also configure queries to only retrieve a specific type of resource.
SearchResult
a collection of search results that match the query parameters specified in the API request. By default, a search result set identifies matching video, channel, and playlist resources, but you can also configure queries to only retrieve a specific type of resource.
SecondaryReason
Snippet
Status
The status object contains information about the event's status.
Subscription
A Subscription resource contains information about a YouTube user subscription. A subscription notifies a user when new videos are added to a channel or when another user takes one of several actions on YouTube, such as uploading a video, rating a video, or commenting on a video.
SubscriptionListResponse
Returns subscription resources that match the API request criteria.
Subscriptions
A subscription resource contains information about a YouTube user subscription. A subscription notifies a user when new videos are added to a channel or when another user takes one of several actions on YouTube, such as uploading a video, rating a video, or commenting on a video.
TextMessageDetails
This object contains details about the text message. It is only present if the message type is textMessageEvent.
Thumbnail
A map of thumbnail images associated with the broadcast. For each nested object in this object, the key is the name of the thumbnail image, and the value is an object that contains other information about the thumbnail.
Thumbnails
A Thumbnail resource identifies different thumbnail image sizes associated with a resource. Please note the following characteristics of thumbnail images:
ThumbnailsSetResponse
TimeStore
Timing
The timing object encapsulates information about the time during a video playback when a channel's watermark image will display.
Token
Util
VideoAbuseReportReason
VideoAbuseReportReasonListResponse
VideoAbuseReportReasons
VideoAbuseReportReasonSnippet
VideoCategories
Returns a list of VideoItems that match the API request parameters.
VideoCategoryListResponse
VideoGetRatingResponse
VideoItem
A video resource represents a YouTube video.
VideoListResponse
Retrieves the ratings that the authorized user gave to a list of specified videos.
Videos
Returns a list of VideoItems that match the API request parameters.
Watermarks
A Watermarks resource identifies an image that displays during playbacks of a specified channel's videos. You can also specify a target channel to which the image will link as well as timing details that determine when the watermark appears during video playbacks and the length of time it is visible.
WatermarksResource
A watermark resource identifies an image that displays during playbacks of a specified channel's videos. You can also specify a target channel to which the image will link as well as timing details that determine when the watermark appears during video playbacks and the length of time it is visible.
Yt

Enums

ListPosition
ModerationStatus
Identifies the new moderation status of the specified comments.
TextFormat
This parameter indicates whether the API should return comments formatted as HTML or as plain text. The default value is html.

Extensions

UsageExtension on DioException

Exceptions / Errors

AuthorizationException