ActivityContentResource class

Contains information about a resource which is the target of a user activity.

Annotations
  • @JsonSerializable.new()

Constructors

ActivityContentResource({Map<String, dynamic>? resourceId})
ActivityContentResource.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
resourceId Map<String, dynamic>?
An object that identifies the resource that the user liked, added to favorites, or commented on.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited