ActivitySnippet class
The snippet object contains basic details about the activity, including the activity's type and group ID.
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
Properties
- channelId → String?
-
The ID that YouTube uses to uniquely identify the channel associated with the activity.
final
- channelTitle → String?
-
Channel title for the channel responsible for this activity.
final
- description → String?
-
The description of the resource primarily associated with the activity.
final
- groupId → String?
-
The group ID associated with the activity.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- publishedAt → String?
-
The date and time that the activity occurred.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thumbnails
→ Map<
String, dynamic> ? -
A map of thumbnail images associated with the resource.
final
- title → String?
-
The title of the resource primarily associated with the activity.
final
- type → String?
-
The type of activity that the resource describes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited