Member class
- Annotations
-
- @JsonSerializable.new()
Constructors
- Member({String kind = 'youtube#member', required String etag, required MemberSnippet snippet})
-
Member.fromJson(Map<
String, dynamic> json) -
factory
Properties
- etag → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snippet → MemberSnippet
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited